SimpleFirstFit

Struct SimpleFirstFit 

pub struct SimpleFirstFit<StateElement, Element> { /* private fields */ }
Simple first fit free block manager, always search free block from memory region head (no free block link list), slowest, lowest internal fragment, lowest code size, and only support single memory region(extend just ignored)

Implementations

Source

impl<StateElement, Element> SimpleFirstFit<StateElement, Element>

pub const fn new() -> Self